using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Drawing;

namespace GeoTools
{
    /// <summary>
    /// [ All public items must be documented. ]
    /// Models a geometrical square.
    /// </summary>
    public class Square
    {
        /// <summary>
        /// Important points in the shape
        /// </summary>
        public float[][] Points { get; private set; }

        /// <summary>
        /// The length of the square edge.
        /// </summary>
        public float Size { get; private set; }

        public float Area { get { return Size * Size;  } }

        public float Perimeter { get { return 4 * Size; } }

        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="x">x-coordinate of the lower-left corner</param>
        /// <param name="y">y-coordinate of the lower-left corner</param>
        /// <param name="l">length of the edge</param>
        public Square(float x, float y, float l)
        {
            Size = l;

            Points = new float[4][];
            Points[0] = new float[] { x, y };
            Points[1] = new float[] { x + l, y };
            Points[2] = new float[] { x + l, y + l };
            Points[3] = new float[] { x, y + l };
        }

        public void Draw(Graphics g)
        {
            g.DrawLine(Pens.Black, Points[0][0], Points[0][1], Points[1][0], Points[1][1]);
            g.DrawLine(Pens.Black, Points[1][0], Points[1][1], Points[2][0], Points[2][1]);
            g.DrawLine(Pens.Black, Points[2][0], Points[2][1], Points[3][0], Points[3][1]);
            g.DrawLine(Pens.Black, Points[3][0], Points[3][1], Points[0][0], Points[0][1]);
        }

        public override string ToString()
        {
            return "square [location:(" + Points[0][0] + "," + Points[0][1] + "), edge length:" + Size + "]";
        }

    }
}
